/* Task Scheduler v0.3
*  ===================
*  Created by PenDragon
*  http://forums.alliedmods.net/member.php?u=155
*  http://forums.alliedmods.net/showthread.php?t=1263
*
*  Version 0.3 modification by Rich Weeds Nagel, October 10, 2013
*
*  Description
*  -----------
*  This plugin is a simple task scheduler to perform a server command at a
*  specified interval (in minutes or seconds), or at a specific time of day.
*
*  Usage
*  -----
*  Add tasks to your "AMX.cfg" AMXModx configuration file using the following
*  format:
*
*  amx_task <time> "server command" <flags>
*
*  Flags
*  -----
*  m - <time> is in minutes.
*  s - <time> is in seconds.
*  r - Repeat task.
*  t - Specific time of day. The format for the <time> variable is in 24-hour
*      format (i.e. HOURS:MINUTES), with a range of 00:00 - 23:59 (e.g. 05:09).
*      Note that the "r" flag is automatically enabled when using the "t" flag.
*
*  Note that the "server command" must be enclosed in double quotes.
*
*  Examples
*  --------
*  To restart a Counter-Strike round every 5 minutes:
*  amx_task 5 "sv_restart 1" mr
*
*  To restart any server at 5:09am every day:
*  amx_task 05:09 "quit" t
*
*  Additional Notes
*  ----------------
*  Note that the "server command" will NOT be executed if the server's map is
*  currently being changed or cycled.
*
*  A workaround is to simply set the <time> variable to a value that is NOT
*  equal to a multiple of the server's "mp_timelimit" setting (the amount of
*  time before the server cycles to the next map in the server's map rotation,
*  which is usually 30 minutes for most servers).
*
*  Version History
*  ---------------
*  Version 0.1 - First Release.
*  Version 0.2 - Changed all of the "time" variables to "clock".
*              - Added "#include <amxmodx>"
*  Version 0.3 - Changed the frequency that the plugin checks for the plugin's
*                variables (i.e. changed set_task(60.0,"check_time",1,"",0,"b")
*                to set_task(30.0,"check_time",1,"",0,"b")).
*
*
*  ENJOY!
*
*  Rich Weeds Nagel
*  October 10, 2013
*
*  AIM: RichFNagel
*  ICQ: 565228098 / RichFNagel
*  Twitter: @RFNagel
*
*  richnagel@centurylink.net
*  richnagel@simpilot.net
*  rfnagel@juno.com
*
*  http://www.richnagel.net
*  http://www.simpilot.net/~richnagel
*  http://jasonwilliams400com.startlogic.com/snor/
*  http://jasonwilliams400com.startlogic.com/snor/weeds/
*  http://jasonwilliams400com.startlogic.com/snor/weeds/Counter_Strike/
*  http://jasonwilliams400com.startlogic.com/snor/weeds/Day_of_Defeat/
*  http://tinyurl.com/TumbleWeedsCSCZDODServerStatus
*  http://www.facebook.com/RFNagel
*  http://www.facebook.com/profile.php?id=1164518241
*  http://steamcommunity.com/id/RichNagel
*  http://steamcommunity.com/groups/SwampBuzzardsClan
*  http://www.youtube.com/RFNagel
*/

#include <amxmodx>

new task_cmds[32][108]
new task_times[32][16]
new numtasks = 0

public load_task()
{
	if (read_argc() < 4) {
		server_print("[AMX] Usage:  amx_task < time > ^"command^" < flags >")
		return PLUGIN_HANDLED
	}

	new args[128]
	read_args(args,128)
	new clock[6], cmd[108], flags[5]

	parse(args,clock,6,cmd,108,flags,5)
	new Float:time_f = floatstr(clock)

	new flag[2] = ""
	if (contain(flags,"r") != -1)
		flag="b"
	if (contain(flags,"m") != -1)
		time_f = time_f * 60

	if (contain(flags,"t") != -1)
	{
		copy(task_cmds[numtasks],108,cmd)
		copy(task_times[numtasks],6,clock)
		numtasks++
		return PLUGIN_HANDLED
	}

	set_task(time_f,"run_task",0,cmd,108,flag)

	return PLUGIN_CONTINUE
}

public run_task(cmd[])
{
	server_cmd(cmd)
	return PLUGIN_HANDLED
}

public check_time()
{
	new curtime[16]
	get_time("%H:%M",curtime,16)

	for(new i=0; i<numtasks; i++)
		if(equal(curtime,task_times[i]))
			server_cmd(task_cmds[i])

	return PLUGIN_CONTINUE
}

public plugin_init()
{
	register_plugin("Task Scheduler","0.3","PenDragon")
	register_srvcmd("amx_task","load_task")
	set_task(30.0,"check_time",1,"",0,"b")
	return PLUGIN_CONTINUE
}
